@@ -34,7 +34,7 @@ class MainPPT():
                 ppt2pdf_single(filename, output_filename)
                 time.sleep(3)
 
-    def ppt2img(self, intput_path, output_path, img_type):
+    def ppt2img(self, input_path, output_path, img_type):
         '''将PPT另存为图片格式
           arguments:
               pptFullName: 要转换的ppt文件，
@@ -46,11 +46,11 @@ class MainPPT():
         # 设置为0表示后台运行，不显示，1则显示
         pptClient.Visible = 1
         # 打开PPT文件
-        ppt = pptClient.Presentations.Open(intput_path)
+        ppt = pptClient.Presentations.Open(input_path)
 
         # 另存为图片
         # Python路径操作模块pathlib，看这篇就够了！ https://zhuanlan.zhihu.com/p/475661402
-        output_dir = Path(output_path) / str(Path(intput_path).stem)
+        output_dir = Path(output_path) / str(Path(input_path).stem)
         if not os.path.exists(output_dir):
             os.mkdir(output_dir)
         # JPG是17
